@@ -6,6 +6,4 @@ from juriscraper.opinions.united_states.state import ala
 
 
 class Site(ala.Site):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.url = "https://judicial.alabama.gov/decision/civildecisions"
+    court_str = "1da1a297-c391-4e4f-9480-1bc68b46f21a"
