@@ -6,6 +6,4 @@ from juriscraper.opinions.united_states.state import ala
 
 
 class Site(ala.Site):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.url = "https://judicial.alabama.gov/decision/criminaldecisions"
+    court_str = "b82b30d5-bd3c-46d7-9451-1cb05e470873"
