@@ -7,11 +7,14 @@ Reviewer: mlr
 History:
     2014-09-03: Created by Jon Andersen
 """
+
 from juriscraper.opinions.united_states.state import ind
 
 
 class Site(ind.Site):
+    page_court_id = "9530"
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.url = "http://www.in.gov/judiciary/opinions/appeals.html"
+        self.court_name = "Court of Appeals"
