@@ -6,7 +6,9 @@
 #          504-310-2592
 #          rgunn@lasc.org
 
+import re
 from datetime import date
+from urllib.parse import urljoin
 
 from juriscraper.lib.html_utils import get_html_parsed_text
 from juriscraper.lib.string_utils import titlecase
@@ -21,7 +23,9 @@ class Site(OpinionSiteLinear):
         self.url = "http://www.lasc.org/CourtActions/%d" % self.year
         self.status = "Published"
 
-    def _download(self, request_dict={}):
+    def _download(self, request_dict=None):
+        if request_dict is None:
+            request_dict = {}
         landing_page = OpinionSiteLinear._download(self, request_dict)
         if self.test_mode_enabled():
             return [self._get_subpage_html_by_page(landing_page)]
@@ -36,29 +40,31 @@ class Site(OpinionSiteLinear):
         return [self._get_subpage_html_by_url(url) for url in urls]
 
     def _process_html(self):
-        path = (
-            "//a["
-            "contains(., 'v.') or "
-            "contains(., 'IN RE') or "
-            "contains(., 'IN THE') or "
-            "contains(., 'vs.') or "
-            "contains(., 'VS.')"
-            "]"
-        )
+        xpath = "//a[contains(@href, 'opinions') and contains(@href, 'pdf')]"
         for html in self.html:
-            for anchor in html.xpath(path):
+            for anchor in html.xpath(xpath):
                 date_string = self._get_date_for_opinions(html)
                 text = anchor.text_content()
                 parts = text.split(None, 1)
                 summary_lines = anchor.getparent().xpath("./text()")
+
+                judge = self._get_judge_above_anchor(anchor)
+                per_curiam = False
+                if "per curiam" in judge.lower():
+                    per_curiam = True
+                    judge = ""
+
                 self.cases.append(
                     {
                         "date": date_string,
                         "docket": parts[0],
-                        "judge": self._get_judge_above_anchor(anchor),
+                        "judge": judge,
+                        "per_curiam": per_curiam,
                         "name": titlecase(parts[1]),
                         "summary": " ".join(summary_lines).replace(text, ""),
-                        "url": anchor.get("href"),
+                        "url": urljoin(
+                            "http://www.lasc.org", anchor.get("href")
+                        ),
                     }
                 )
 
@@ -73,10 +79,7 @@ class Site(OpinionSiteLinear):
 
     def _get_judge_above_anchor(self, anchor):
         path = (
-            "./preceding::*["
-            "starts-with(., 'BY ') or "
-            "contains(., 'CURIAM:')"
-            "]"
+            "./preceding::*[starts-with(., 'BY ') or contains(., 'CURIAM:')]"
         )
         try:
             text = anchor.xpath(path)[-1].text_content()
@@ -92,3 +95,35 @@ class Site(OpinionSiteLinear):
         path = ".//textarea[@id='PostContent']"
         html = page.xpath(path)[0].text_content()
         return get_html_parsed_text(html)
+
+    def extract_from_text(self, scraped_text: str) -> dict:
+        """Extract lower court from the scraped text.
+
+        :param scraped_text: The text to extract from.
+        :return: A dictionary with the metadata.
+        """
+        pattern = re.compile(
+            r"""
+            (?:
+               On\s+Writ\s+of\s+Certiorari\s+to\s+the\s+
+               |On\s+Supervisory\s+Writ\s+to\s+the\s+
+            )
+            (?P<lower_court>.*?)\n\s*\n
+            """,
+            re.X | re.DOTALL,
+        )
+
+        lower_court = ""
+        if match := pattern.search(scraped_text):
+            lower_court = re.sub(
+                r"\s+", " ", match.group("lower_court")
+            ).strip()
+
+        if lower_court:
+            return {
+                "Docket": {
+                    "appeal_from_str": lower_court,
+                }
+            }
+
+        return {}
