@@ -11,5 +11,5 @@ from juriscraper.opinions.united_states.state import nyappterm_1st
 class Site(nyappterm_1st.Site):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.court = "Appellate+Term,+2d+Dept"
+        self.court = "Appellate Term, 2d Dept"
         self.parameters.update({"court": self.court})
