@@ -3,6 +3,9 @@ Scraper for the Tennessee Court of Appeals
 CourtID: tennctapp
 Court Short Name: Tenn. Ct. App.
 """
+
+from datetime import datetime
+
 from juriscraper.opinions.united_states.state import tenn
 
 
@@ -10,5 +13,5 @@ class Site(tenn.Site):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.court_id = self.__module__
-        self.url = "http://www.tsc.state.tn.us/courts/court-appeals/opinions"
-        self.back_scrape_iterable = list(range(0, 987))
+        self.url = "https://www.tncourts.gov/courts/court-appeals/opinions"
+        self.first_opinion_date = datetime(1988, 10, 7)
