@@ -13,6 +13,6 @@ from juriscraper.opinions.united_states_backscrapers.federal_district import (
 
 class Site(dcd_2013.Site):
     def __init__(self, *args, **kwargs):
-        super(Site, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.court_id = self.__module__
         self.url = "https://ecf.dcd.uscourts.gov/cgi-bin/Opinions.pl?2011"
