@@ -15,15 +15,14 @@ class Site(OpinionSite):
         self.court_id = self.__module__
 
     def _get_case_names(self):
-        return [t for t in self.html.xpath("//table//tr/td[1]/font/text()")]
+        return list(self.html.xpath("//table//tr/td[1]/font/text()"))
 
     def _get_download_urls(self):
-        return [
-            t
-            for t in self.html.xpath(
+        return list(
+            self.html.xpath(
                 '//table//tr/td[2]/font/a/@href[contains(., ".pdf")]'
             )
-        ]
+        )
 
     def _get_case_dates(self):
         dates = []
