@@ -8,10 +8,9 @@ __all__ = [
     "ca7",
     "ca8",
     "ca9",
-    "ca10",  # FINALLY!
+    "ca10",
     "ca11",
     "cadc",
     "cafc",
     "scotus",
-    # 'scotusoyez',
 ]
