@@ -2,10 +2,17 @@ import pprint
 import re
 import sys
 
-from ..lib.log_tools import make_default_logger
-from ..lib.string_utils import force_unicode
+from juriscraper.lib.log_tools import make_default_logger
+from juriscraper.lib.string_utils import force_unicode
+
 from .reports import BaseReport
-from .utils import get_pacer_doc_id_from_doc1_url, reverse_goDLS_function
+from .utils import (
+    get_court_id_from_doc_id_prefix,
+    get_file_size_str_from_tr,
+    get_input_value_from_tr,
+    get_pacer_doc_id_from_doc1_url,
+    reverse_goDLS_function,
+)
 
 logger = make_default_logger()
 
@@ -27,9 +34,9 @@ class AttachmentPage(BaseReport):
         :param document_number: The internal PACER document ID for the item.
         :return: a request response object
         """
-        assert (
-            self.session is not None
-        ), "session attribute of DocketReport cannot be None."
+        assert self.session is not None, (
+            "session attribute of DocketReport cannot be None."
+        )
         # coerce the fourth digit of the document number to 1 to ensure we get
         # the attachment page.
         document_number = f"{document_number[:3]}0{document_number[4:]}"
@@ -66,37 +73,46 @@ class AttachmentPage(BaseReport):
             logger.info("No documents found on attachment page.")
             return {}
 
-        first_row = rows.pop(0)
+        first_num = self._get_name_attachment_number(rows[0])
+        # First row is an attachment
+        if first_num is not None and first_num != 0:
+            first_row = rows[0]
+            first_row_attachment = True
+        else:
+            first_row = rows.pop(0)
+            first_row_attachment = False
         result = {
             "document_number": self._get_document_number(),
-            "page_count": self._get_page_count_from_tr(first_row),
-            "file_size_str": self._get_file_size_str_from_tr(first_row),
             "pacer_doc_id": self._get_pacer_doc_id(first_row),
             "pacer_case_id": self._get_pacer_case_id(),
             "pacer_seq_no": self._get_pacer_seq_no_from_tr(first_row),
             "attachments": [],
         }
-        if result["document_number"] is None and not self.is_bankruptcy:
-            # Abort. Sometimes some attachment pages we receive have a blank
-            # area instead of having a proper document number. When going to
-            # PACER to reproduce this, things look fine, so I don't know why we
-            # get the bad data. In any case, simply give up since we can't do
-            # much without a document number.
-            return {}
+        if first_row_attachment:
+            result["page_count"] = None
+            result["file_size_str"] = ""
+        else:
+            result["page_count"] = self._get_page_count_from_tr(first_row)
+            file_size_bytes = self._get_file_size_bytes_from_tr(first_row)
+            if file_size_bytes is not None:
+                result["file_size_bytes"] = file_size_bytes
+            result["file_size_str"] = get_file_size_str_from_tr(first_row)
         for row in rows:
-            result["attachments"].append(
-                {
-                    "attachment_number": self._get_attachment_number(row),
-                    "description": self._get_description_from_tr(row),
-                    "page_count": self._get_page_count_from_tr(row),
-                    "file_size_str": self._get_file_size_str_from_tr(row),
-                    "pacer_doc_id": self._get_pacer_doc_id(row),
-                    # It may not be needed to reparse the seq_no
-                    # for each row, but we may as well. So far, it
-                    # has always been the same as the main document.
-                    "pacer_seq_no": self._get_pacer_seq_no_from_tr(row),
-                }
-            )
+            attachment = {
+                "attachment_number": self._get_attachment_number(row),
+                "description": self._get_description_from_tr(row),
+                "page_count": self._get_page_count_from_tr(row),
+                "file_size_str": get_file_size_str_from_tr(row),
+                "pacer_doc_id": self._get_pacer_doc_id(row),
+                # It may not be needed to reparse the seq_no
+                # for each row, but we may as well. So far, it
+                # has always been the same as the main document.
+                "pacer_seq_no": self._get_pacer_seq_no_from_tr(row),
+            }
+            file_size_bytes = self._get_file_size_bytes_from_tr(row)
+            if file_size_bytes is not None:
+                attachment["file_size_bytes"] = file_size_bytes
+            result["attachments"].append(attachment)
 
         return result
 
@@ -104,8 +120,28 @@ class AttachmentPage(BaseReport):
         """Return the document number for an item.
 
         In district court attachment pages, this is easy to extract with an
-        XPath. In bankruptcy cases, it's simply not there.
+        XPath. In bankruptcy cases, it's sometimes not there.
         """
+        # First try inspecting the input elements
+        input_els = self.tree.xpath("//input")
+        for input_el in input_els:
+            try:
+                name = input_el.xpath("./@name")[0]
+            except IndexError:
+                continue
+            else:
+                split = name.split("_")
+                # Document 16 name field example "document_16_0"
+                if len(split) == 3 and split[0] == "document":
+                    document_string = split[1]
+                    # Any other matches will be invalid if this is empty
+                    if document_string == "":
+                        return None
+                    document_number = int(document_string)
+                    # Ensure document number is valid
+                    if document_number != 0:
+                        return document_number
+
         if self.is_bankruptcy:
             return None
 
@@ -121,6 +157,85 @@ class AttachmentPage(BaseReport):
                 continue
         return None
 
+    def _decrement_attachment_index(self, row):
+        """Return if we need to decrement the attachment index.
+
+        We need to do this for all bankruptcy courts and old attachment pages
+        in some district courts.
+
+        For district courts we need to use a mapping table with the last dlsid
+        that requires a decrement.
+
+        Note that the decrement check must be done for each row in case any
+        attachments in the page have sequences after the changeover as any
+        updated attachments with a dlsid after the changeover should not be
+        decremented.
+        """
+        sub_dlsid = {
+            "akd": 682797,
+            "ared": 1906030,
+            "cacd": 9630188,
+            "ctd": 2414673,
+            "flmd": 7734601,
+            "flnd": 2613796,
+            "gamd": 995021,
+            "gasd": 1159201,
+            "hid": 1078891,
+            "ilnd": 8278610,
+            "iand": 899130,
+            "innd": 1560410,
+            "iasd": 1192972,
+            "kyed": 2087957,
+            "kywd": 1738484,
+            "mad": 3618527,
+            "mied": 4148337,
+            "miwd": 2358030,
+            "moed": 3299716,
+            "msnd": 888190,
+            "mssd": 2476698,
+            "nced": 1868202,
+            "ncmd": 1093535,
+            "ndd": 299419,
+            "ned": 1868173,
+            "nvd": 3153010,
+            "nyed": 6778644,
+            "nynd": 1829022,
+            "nysd": 8012889,
+            "nywd": 1862410,
+            "oked": 388419,
+            "ord": 3322370,
+            "pamd": 3122200,
+            "sdd": 1239147,
+            "txed": 3830781,
+            "txnd": 4975453,
+            "utd": 1745928,
+            "vaed": 1338618,
+            "waed": 1349144,
+            "wawd": 3755107,
+            "wied": 1420356,
+            "wyd": 797428,
+        }
+        if self.is_bankruptcy:
+            return True
+        doc_id = self._get_pacer_doc_id(row)
+        court_id = get_court_id_from_doc_id_prefix(doc_id[:3])
+        if court_id not in sub_dlsid:
+            return False
+        dlsid = int(doc_id[3:])
+        return sub_dlsid[court_id] >= dlsid
+
+    def _get_name_attachment_number(self, row):
+        try:
+            name = row.xpath(".//input/@name")[0]
+        except IndexError:
+            return None
+        else:
+            split = name.split("_")
+            # Document 16 name field example "document_16_0"
+            if len(split) == 3 and split[0] == "document":
+                return int(split[2])
+        return None
+
     def _get_attachment_number(self, row):
         """Return the attachment number for an item.
 
@@ -128,22 +243,26 @@ class AttachmentPage(BaseReport):
         you must extract it, then subtract 1 from the value since these are
         tallied and include the main document.
         """
-        number = int(row.xpath(".//a/text()")[0].strip())
-        if self.is_bankruptcy:
+        number = self._get_name_attachment_number(row)
+        if number is None:
+            number = int(row.xpath(".//a/text()")[0].strip())
+        if self._decrement_attachment_index(row):
             return number - 1
         return number
 
     def _get_description_from_tr(self, row):
         """Get the description from the row"""
+        columns_in_row = row.xpath("./td")
         if not self.is_bankruptcy:
             index = 2
             # Some NEFs attachment pages for some courts have an extra column
             # (see nyed_123019137279), use index 3 to get the description
-            columns_in_row = row.xpath(f"./td")
             if len(columns_in_row) == 5:
                 index = 3
         else:
             index = 3
+            if len(columns_in_row) == 6:
+                index = 4
 
         description_text_nodes = row.xpath(f"./td[{index}]//text()")
         if not description_text_nodes:
@@ -152,11 +271,23 @@ class AttachmentPage(BaseReport):
         description = description_text_nodes[0].strip()
         return force_unicode(description)
 
+    @staticmethod
+    def _get_page_count_from_tr_input_value(tr):
+        """Take a row from the attachment table and return the page count as an
+        int extracted from the input value.
+        """
+        count = get_input_value_from_tr(tr, 2, 3, "-")
+        if count is not None:
+            return int(count)
+
     @staticmethod
     def _get_page_count_from_tr(tr):
         """Take a row from the attachment table and return the page count as an
         int extracted from the cell specified by index.
         """
+        pg_cnt_input = AttachmentPage._get_page_count_from_tr_input_value(tr)
+        if pg_cnt_input:
+            return pg_cnt_input
         pg_cnt_str_nodes = tr.xpath('./td[contains(., "page")]/text()')
         if not pg_cnt_str_nodes:
             # It's a restricted document without page count information.
@@ -173,16 +304,17 @@ class AttachmentPage(BaseReport):
                 continue
 
     @staticmethod
-    def _get_file_size_str_from_tr(tr):
+    def _get_file_size_bytes_from_tr(tr):
         """Take a row from the attachment table and return the number of bytes
         as an int.
         """
-        cells = tr.xpath("./td")
-        last_cell_contents = cells[-1].text_content()
-        units = ["kb", "mb"]
-        if any(unit in last_cell_contents.lower() for unit in units):
-            return last_cell_contents.strip()
-        return ""
+        file_size_str = get_input_value_from_tr(tr, 1, 3, "-")
+        if file_size_str is None:
+            return None
+        file_size = int(file_size_str)
+        if file_size == 0:
+            return None
+        return file_size
 
     @staticmethod
     def _get_pacer_doc_id(row):
@@ -201,26 +333,29 @@ class AttachmentPage(BaseReport):
             doc1_url = url.xpath("./@href")[0]
             return get_pacer_doc_id_from_doc1_url(doc1_url)
 
-    @staticmethod
-    def _get_pacer_seq_no_from_tr(row):
+    def _get_pacer_seq_no_from_tr(self, row):
         """Take a row of the attachment page, and return the sequence number
         from the goDLS function.
         """
-        try:
-            url = row.xpath(".//a")[0]
-        except IndexError:
-            # No link in the row. Maybe its sealed.
-            pass
-        else:
+        url = row.xpath(".//a")
+        if url:
+            onclick = url[0].xpath("./@onclick")
+            if onclick and "goDLS" in onclick[0]:
+                go_dls_parts = reverse_goDLS_function(onclick[0])
+                return go_dls_parts["de_seq_num"]
+
+        input_els = self.tree.xpath("//input")
+        for input_el in input_els:
             try:
-                onclick = url.xpath("./@onclick")[0]
+                onclick = input_el.xpath("./@onclick")[0]
             except IndexError:
-                # No onclick on this row.
-                pass
+                continue
             else:
-                if "goDLS" in onclick:
-                    go_dls_parts = reverse_goDLS_function(onclick)
-                    return go_dls_parts["de_seq_num"]
+                m = re.search(
+                    r"[?&]arr_de_seq_nums=(\d+)", onclick, flags=re.I
+                )
+                if m:
+                    return m.group(1)
 
         # 1. Couldn't find a link in the row: Maybe it's sealed.
         # 2. No onclick on the row.
