@@ -1,18 +1,29 @@
+import gzip
 import json
 import re
 
 import requests
 from requests.packages.urllib3 import exceptions
 
-from ..lib.exceptions import PacerLoginException
-from ..lib.html_utils import get_html_parsed_text, get_xml_parsed_text
-from ..lib.log_tools import make_default_logger
-from ..pacer.utils import is_pdf, is_text
+from juriscraper.lib.exceptions import PacerLoginException
+from juriscraper.lib.html_utils import (
+    get_html_parsed_text,
+    get_xml_parsed_text,
+    strip_bad_html_tags_insecure,
+)
+from juriscraper.lib.log_tools import make_default_logger
+from juriscraper.pacer.utils import is_pdf, is_text
 
 logger = make_default_logger()
 
 requests.packages.urllib3.disable_warnings(exceptions.InsecureRequestWarning)
 
+# Compile the regex pattern once for efficiency.
+# This pattern captures the court_id (e.g., 'ca9', 'ca2') from the URL.
+ACMS_URL_PATTERN = re.compile(
+    r"https?://(ca\d+)-showdoc(services)?\.azurewebsites\.us/.*"
+)
+
 
 def check_if_logged_in_page(content: bytes) -> bool:
     """Is this a valid HTML page from PACER?
@@ -41,16 +52,13 @@ def check_if_logged_in_page(content: bytes) -> bool:
         ]
     ):
         not_logged_in = re.search(b"text.*Not logged in", content)
-        if not_logged_in:
-            # An unauthenticated PossibleCaseNumberApi XML result. Simply
-            # continue onwards. The complete result looks like:
-            # <request number='1501084'>
-            #   <message text='Not logged in.  Please refresh this page.'/>
-            # </request>
-            # An authenticated PossibleCaseNumberApi XML result.
-            return False
-        else:
-            return True
+        # An unauthenticated PossibleCaseNumberApi XML result. Simply
+        # continue onwards. The complete result looks like:
+        # <request number='1501084'>
+        #   <message text='Not logged in.  Please refresh this page.'/>
+        # </request>
+        # An authenticated PossibleCaseNumberApi XML result.
+        return not not_logged_in
 
     # Detect if we are logged in. If so, no need to do so. If not, we login
     # again below.
@@ -72,7 +80,7 @@ def check_if_logged_in_page(content: bytes) -> bool:
     appellate_document_error = (
         b"The requested document cannot be displayed" in content
     )
-    if any(
+    return any(
         [
             found_district_logout_link,
             found_appellate_logout_link,
@@ -80,11 +88,7 @@ def check_if_logged_in_page(content: bytes) -> bool:
             appellate_attachment_page,
             appellate_document_error,
         ]
-    ):
-        # A normal HTML page we're logged into.
-        return True
-
-    return False
+    )
 
 
 class PacerSession(requests.Session):
@@ -99,7 +103,12 @@ class PacerSession(requests.Session):
     LOGIN_URL = "https://pacer.login.uscourts.gov/services/cso-auth"
 
     def __init__(
-        self, cookies=None, username=None, password=None, client_code=None
+        self,
+        cookies=None,
+        username=None,
+        password=None,
+        client_code=None,
+        get_acms_tokens=False,
     ):
         """
         Instantiate a new PACER API Session with some Juriscraper defaults
@@ -107,6 +116,7 @@ class PacerSession(requests.Session):
         :param username: a PACER account username
         :param password: a PACER account password
         :param client_code: an optional PACER client code for the session
+        :param get_acms_tokens: boolean flag to enable ACMS authentication during login.
         """
         super().__init__()
         self.headers["User-Agent"] = "Juriscraper"
@@ -124,6 +134,36 @@ class PacerSession(requests.Session):
         self.password = password
         self.client_code = client_code
         self.additional_request_done = False
+        self.get_acms_tokens = get_acms_tokens
+        self.acms_user_data = {}
+        self.acms_tokens = {}
+
+    def _check_url_and_retrieve_acms_token(self, url: str) -> str:
+        """
+        Checks if the provided URL is an ACMS URL and, if so, ensures the
+        ACMS bearer token is available for that court ID.
+
+        If the ACMS bearer token for the detected court ID is not already
+        in the session's `acms_tokens`, this method will trigger the
+        `get_acms_auth_object()` method to perform authentication and
+        retrieve the token.
+
+        :param url: The URL of the request to check.
+        :return: The ACMS bearer token if the URL is an ACMS URL and a token
+                 is available. Returns an empty string otherwise
+        """
+        # Check if the URL matches the ACMS pattern
+        match = ACMS_URL_PATTERN.match(url)
+        if not match:
+            return ""
+
+        acms_court_id = match.group(1)
+        logger.debug(f"Detected ACMS request for court: {acms_court_id}")
+
+        if acms_court_id not in self.acms_tokens:
+            self.get_acms_auth_object(acms_court_id)
+
+        return self.acms_tokens[acms_court_id]["Token"]
 
     def get(self, url, auto_login=True, **kwargs):
         """Overrides request.Session.get with session retry logic.
@@ -132,7 +172,17 @@ class PacerSession(requests.Session):
         :param auto_login: Whether the auto-login procedure should happen.
         :return: requests.Response
         """
-        kwargs.setdefault("timeout", 300)
+        # Check if the URL matches the ACMS pattern
+        acms_token = self._check_url_and_retrieve_acms_token(url)
+        # If it's an ACMS request, add the bearer token to the headers
+        if acms_token:
+            # Ensure 'headers' key exists in kwargs as a dictionary.
+            # If it doesn't exist, it's created as an empty dict.
+            kwargs.setdefault("headers", {})
+            kwargs["headers"].update({"Authorization": f"Bearer {acms_token}"})
+
+        if "timeout" not in kwargs:
+            kwargs.setdefault("timeout", 300)
 
         r = super().get(url, **kwargs)
 
@@ -145,7 +195,7 @@ class PacerSession(requests.Session):
             # request, so that's what we do here. PACER needs some frustrating
             # and inelegant hacks sometimes.
             r = super().get(url, **kwargs)
-        if auto_login:
+        if auto_login and not acms_token:
             updated = self._login_again(r)
             if updated:
                 # Re-do the request with the new session.
@@ -171,6 +221,15 @@ class PacerSession(requests.Session):
         :param kwargs: assorted keyword arguments
         :return: requests.Response
         """
+        # Check if the URL matches the ACMS pattern
+        acms_token = self._check_url_and_retrieve_acms_token(url)
+        # If it's an ACMS request, add the bearer token to the headers
+        if acms_token:
+            # Ensure 'headers' key exists in kwargs as a dictionary.
+            # If it doesn't exist, it's created as an empty dict.
+            kwargs.setdefault("headers", {})
+            kwargs["headers"].update({"Authorization": f"Bearer {acms_token}"})
+
         kwargs.setdefault("timeout", 300)
 
         if data:
@@ -180,7 +239,7 @@ class PacerSession(requests.Session):
             kwargs.update({"data": data, "json": json})
 
         r = super().post(url, **kwargs)
-        if auto_login:
+        if auto_login and not acms_token:
             updated = self._login_again(r)
             if updated:
                 # Re-do the request with the new session.
@@ -206,7 +265,7 @@ class PacerSession(requests.Session):
         :param data: dict of data to transform
         :return: dict with values wrapped into tuples like:(None, <value>)
         """
-        output = dict()
+        output = {}
         for key in data:
             output[key] = (None, data[key])
         return output
@@ -262,6 +321,29 @@ class PacerSession(requests.Session):
         xpath = "//update[@id='j_id1:javax.faces.ViewState:0']/text()"
         return tree.xpath(xpath)[0]
 
+    def _prepare_login_request(self, url, data, headers, *args, **kwargs):
+        """Prepares and sends a POST request for login purposes.
+
+        This internal helper function constructs a POST request to the provided URL
+        using the given headers and data. It sets a timeout of 60 seconds for the
+        request.
+
+        :param url: The URL of the login endpoint.
+        :param data: A dictionary containing login credentials.
+        :param headers: Additional headers to include in the request.
+        :param *args: Additional arguments to be passed to the underlying POST
+               request.
+        :param **kwargs: Additional keyword arguments to be passed to the
+               underlying POST request.
+        :return: requests.Response: The response object from the login request.
+        """
+        return super().post(
+            url,
+            headers=headers,
+            timeout=60,
+            data=data,
+        )
+
     def login(self, url=None):
         """Attempt to log into the PACER site.
         The first step is to get an authentication token using a PACER
@@ -295,15 +377,13 @@ class PacerSession(requests.Session):
         if self.client_code:
             data["clientCode"] = self.client_code
 
-        login_post_r = super().post(
-            url,
-            headers={
-                "User-Agent": "Juriscraper",
-                "Content-type": "application/json",
-                "Accept": "application/json",
-            },
-            timeout=60,
-            data=json.dumps(data),
+        headers = {
+            "User-Agent": "Juriscraper",
+            "Content-type": "application/json",
+            "Accept": "application/json",
+        }
+        login_post_r = self._prepare_login_request(
+            url, data=json.dumps(data), headers=headers
         )
 
         if login_post_r.status_code != requests.codes.ok:
@@ -316,7 +396,7 @@ class PacerSession(requests.Session):
 
         # 'loginResult': '0', user successfully logged; '1', user not logged
         if (
-            response_json.get("loginResult") == None
+            response_json.get("loginResult") is None
             or response_json.get("loginResult") == "1"
         ):
             message = f"Invalid username/password: {response_json.get('errorDescription')}"
@@ -359,6 +439,10 @@ class PacerSession(requests.Session):
         self.cookies = session_cookies
         logger.info("New PACER session established.")
 
+        if self.get_acms_tokens:
+            for court_id in ["ca2", "ca9"]:
+                self.get_acms_auth_object(court_id)
+
     def _do_additional_request(self, r: requests.Response) -> bool:
         """Check if we should do an additional request to PACER, sometimes
         PACER returns the login page even though cookies are still valid.
@@ -405,3 +489,109 @@ class PacerSession(requests.Session):
                 "Invalid/expired PACER session and do not have credentials "
                 "for re-login."
             )
+
+    def _get_docket_sheet_url(self, court_id: str) -> str:
+        """
+        Retrieves the base docket sheet URL for a given court ID. This URL
+        serves as the initial entry point to trigger the authentication flow.
+
+        :param court_id: The court identifier
+        :return: The corresponding docket sheet URL.
+        """
+        if court_id == "ca9":
+            return "https://ca9-showdoc.azurewebsites.us/"
+        elif court_id == "ca2":
+            return "https://ca2-showdoc.azurewebsites.us/"
+        else:
+            raise NotImplementedError(
+                f"Docket sheet URL not implemented for court_id: {court_id}"
+            )
+
+    def _get_saml_auth_request_parameters(
+        self, court_id: str
+    ) -> dict[str, str]:
+        """
+        Retrieves SAML authentication request parameters by initiating a request
+        to the DOCKET_SHEET_URL. This simulates the initial browser interaction
+        that triggers the SAML flow, parsing hidden input fields from the
+        response.
+
+        :param court_id: The court identifier.
+        :return: A dictionary where keys are the 'name' attributes and values are
+            the 'value' attributes of hidden input elements found in the SAML
+            authentication request form.
+        """
+        headers = {
+            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8",
+            "Accept-Encoding": "gzip, deflate, br",
+        }
+        logger.info(f"Attempting to get SAML credentials for {court_id}")
+        # Base URL for retrieving SAML credentials.
+        url = self._get_docket_sheet_url(court_id)
+        response = self._prepare_login_request(url, data={}, headers=headers)
+        result_parts = response.text.split("\r\n")
+        # Handle gzip decoding
+        js_screen = result_parts[-1]
+        try:
+            # Try to decompress if it's gzipped
+            inflated_screen = gzip.decompress(js_screen.encode()).decode()
+        except Exception:
+            # If decompression fails, use the original
+            inflated_screen = js_screen
+
+        # Strip potentially problematic HTML tags for safer parsing.
+        html = strip_bad_html_tags_insecure(inflated_screen)
+        # Extract all hidden input elements from the HTML.
+        hidden_inputs = html.xpath('//input[@type="hidden"]')
+
+        # Return a dictionary of hidden input names and their values.
+        return {
+            input_element.get("name"): input_element.get("value")
+            for input_element in hidden_inputs
+        }
+
+    def get_acms_auth_object(self, court_id: str):
+        """
+        Retrieves the ACMS authentication object by submitting SAML parameters
+        to the SAML_URL. This object typically contains the authentication token
+        and other session-related data.
+
+        This method parses the HTML response to extract a JavaScript  variable
+        named 'model', which contains the authentication data. This is
+        necessary because the authentication data is embedded directly within
+        a script tag in the response HTML.
+
+        :param court_id: The court identifier.
+        :return: A dictionary representing the ACMS authentication object if
+            successfully extracted and parsed from the response.
+        """
+        auth_params = self._get_saml_auth_request_parameters(court_id)
+        if not auth_params:
+            raise PacerLoginException(
+                "Failed to extract ACMS authentication data from SAML response."
+            )
+
+        headers = {"Content-Type": "application/x-www-form-urlencoded"}
+        logger.info("Attempting to retrieve ACMS authentication token")
+        saml_url = f"https://{court_id}-showdoc.azurewebsites.us/Saml2/Acs"
+        response = self._prepare_login_request(
+            saml_url, data=auth_params, headers=headers
+        )
+        match = re.search(r"var model = '(.*?)';", response.text)
+        if not match:
+            raise PacerLoginException(
+                "Failed to extract ACMS authentication data from SAML response."
+            )
+
+        model_value = match.group(1)
+        model_string = re.sub("&quot;", '"', model_value)
+        model_json = json.loads(model_string)
+
+        if not self.acms_user_data:
+            data = model_json["PacerUser"]
+            self.acms_user_data = {
+                "CsoId": data["CsoId"],
+                "ContactType": data["ContactType"],
+            }
+
+        self.acms_tokens[court_id] = model_json["AuthToken"]
