@@ -4,13 +4,15 @@ import pprint
 import re
 import sys
 from html import unescape
+from typing import Union
 
 import feedparser
 from requests import Session
 
-from ..lib.log_tools import make_default_logger
-from ..lib.string_utils import clean_string, harmonize
-from ..lib.utils import clean_court_object
+from juriscraper.lib.log_tools import make_default_logger
+from juriscraper.lib.string_utils import clean_string, harmonize
+from juriscraper.lib.utils import clean_court_object
+
 from .docket_report import DocketReport
 from .utils import (
     get_pacer_case_id_from_nonce_url,
@@ -99,10 +101,15 @@ def append_or_merge_entry(docket_list, new_docket):
         same_doc_id = entry["pacer_doc_id"] == new_entry["pacer_doc_id"]
         if all([same_dn, same_cn, same_date, same_doc_id]):
             # if docket number, pacer_case_id, date filing, and pacer_doc_id
-            # are same, merge.
-            entry[
-                "short_description"
-            ] += f" AND {new_entry['short_description']}"
+            # are same, order short descriptions alphabetically and merge.
+
+            short_descriptions = [
+                desc.strip()
+                for desc in entry["short_description"].split("AND")
+            ]
+            short_descriptions.append(new_entry["short_description"])
+            short_description = " AND ".join(sorted(short_descriptions))
+            entry["short_description"] = short_description
             break
     else:
         # Loop exited without hitting a break; item is distinct; append.
@@ -237,12 +244,17 @@ class PacerRssFeed(DocketReport):
         if self.is_valid is False:
             return {}
 
+        docket_number, docket_number_components = self._parse_docket_number(
+            entry.title
+        )
         data = {
             "court_id": self.court_id,
-            "pacer_case_id": get_pacer_case_id_from_nonce_url(entry.link)
-            if not self.is_appellate
-            else None,
-            "docket_number": self._get_docket_number(entry.title),
+            "pacer_case_id": (
+                get_pacer_case_id_from_nonce_url(entry.link)
+                if not self.is_appellate
+                else None
+            ),
+            "docket_number": docket_number,
             "case_name": self._get_case_name(entry.title),
             # Filing date is not available. Also the case for free opinions.
             "date_filed": None,
@@ -263,6 +275,8 @@ class PacerRssFeed(DocketReport):
             "chapter": "",
         }
         data.update(self._parse_get_trustee_type_office_chapter(entry.summary))
+        # Include the docket_number components.
+        data.update(docket_number_components)
         data = clean_court_object(data)
         return data
 
@@ -327,7 +341,18 @@ class PacerRssFeed(DocketReport):
             "trustee_str": m.group("trustee") or "",
         }
 
-    def _get_docket_number(self, title_text):
+    def _parse_docket_number(
+        self, title_text
+    ) -> tuple[Union[str, None], dict[str, Union[str, None]]]:
+        """Parse docket numbers from a list of potential ones. Also parse
+        the docket number components.
+
+        :param title_text: The potential docket number unicode objects
+        :return: A two-tuple: the docket_number and a dict containing the
+        docket_number components if a valid docket number was found.
+        Otherwise, None and the default docket_number components dict with None
+        values.
+        """
         if self.is_bankruptcy:
             # Uses both b/c sometimes the bankr. cases have a dist-style docket
             # number.
@@ -342,7 +367,11 @@ class PacerRssFeed(DocketReport):
         for regex in regexes:
             match = regex.search(title_text)
             if match:
-                return match.group(1)
+                docket_number_components = self._parse_dn_components(
+                    title_text
+                )
+                return match.group(1), docket_number_components
+        return None, self._return_default_dn_components()
 
     def _get_case_name(self, title_text):
         # 1:18-cv-04423 Chau v. Gorg &amp; Smith et al --> Chau v. Gorg & Smith
@@ -401,7 +430,7 @@ sorry if that was your filename.""",
                 "Reading RSS feed from %s as %s"
                 % (args.court_or_file, feed.court_id)
             )
-            f = open(args.court_or_file)
+            f = open(args.court_or_file)  # noqa: SIM115
         feed._parse_text(f.read().decode("utf-8"))
 
     print(f"Got {len(feed.data)} items")
